@@ -5,23 +5,25 @@ use warnings;
 
 use 5.008;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 NAME
 
-Perl6::Cookbook - Examples in Perl 6
+Perl6::Cookbook - The Perl Cookbook examples implemented in Perl 6
 
 =head1 SYNOPSIS
 
+After installation run the C<perl6_cookbook> script to find out 
+where were the examples installed.
+
 =head1 DESCRIPTION
 
-See also
-Rakudo Feature status:
+See also Rakudo Feature status:
 L<http://www.perlfoundation.org/perl6/index.cgi?rakudo_feature_status>
 
 =head1 COPYRIGHT
 
-Copyright 2008 Gabor Szabo. L<http://www.szabgab.com/>
+Copyright 2009 Gabor Szabo. L<http://www.szabgab.com/>
 
 =head1 LICENSE
 
@@ -31,5 +33,3 @@ modify it under the same terms as Perl 5 itself.
 =cut
 
 1;
-
-
